@@ -7,6 +7,7 @@
 
 #include "history.h"
 #include "keymap.h"
+#include "lineview.h"
 #include "listwidget.h"
 #include "stflpp.h"
 
@@ -14,6 +15,7 @@ namespace newsboat {
 
 class ConfigContainer;
 class RssFeed;
+class TextviewWidget;
 class View;
 
 typedef std::pair<std::string, std::string> QnaPair;
@@ -34,12 +36,29 @@ enum class CommandType {
 struct Command {
 	CommandType type;
 	std::vector<std::string> args;
+
+	Command(CommandType type, std::vector<std::string> args = {})
+		: type(type)
+		, args(args)
+	{}
+};
+
+enum class QnaFinishAction {
+	None,
+	Bookmark,
+	RunCmdLine,
+	GotoUrlByNumber,
+	UpdateFlags,
+	Search,
+	PipeItemIntoProgram,
+	GotoTitle,
+	SetFilter,
 };
 
 class FormAction {
 public:
-	FormAction(View*, std::string formstr, ConfigContainer* cfg);
-	virtual ~FormAction();
+	FormAction(View&, std::string formstr, ConfigContainer* cfg);
+	virtual ~FormAction() = default;
 	virtual void prepare() = 0;
 	virtual void init() = 0;
 	virtual void set_redraw(bool b)
@@ -47,12 +66,13 @@ public:
 		do_redraw = b;
 	}
 
-	virtual const std::vector<KeyMapHintEntry>& get_keymap_hint() const = 0;
+	virtual std::vector<KeyMapHintEntry> get_keymap_hint() const = 0;
 
 	virtual std::string id() const = 0;
 
 	std::string get_value(const std::string& name);
 	void set_value(const std::string& name, const std::string& value);
+	void set_status(const std::string& text);
 
 	void draw_form();
 	std::string draw_form_wait_for_event(unsigned int timeout);
@@ -61,16 +81,20 @@ public:
 	virtual void handle_cmdline(const std::string& cmd);
 
 	bool process_op(Operation op,
-		bool automatic = false,
-		std::vector<std::string>* args = nullptr);
+		const std::vector<std::string>& args,
+		BindingType bindingType = BindingType::BindKey);
 
-	virtual void finished_qna(Operation op);
+	virtual void finished_qna(QnaFinishAction op);
 
 	void start_cmdline(std::string default_value = "");
 
 	void start_qna(const std::vector<QnaPair>& prompts,
-		Operation finish_op,
+		QnaFinishAction finish_op,
 		History* h = nullptr);
+	void finish_qna_question();
+	void cancel_qna();
+	void qna_next_history();
+	void qna_previous_history();
 
 	void set_parent_formaction(std::shared_ptr<FormAction> fa)
 	{
@@ -99,9 +123,15 @@ public:
 
 protected:
 	virtual bool process_operation(Operation op,
-		bool automatic = false,
-		std::vector<std::string>* args = nullptr) = 0;
-	virtual void set_keymap_hints();
+		const std::vector<std::string>& args,
+		BindingType bindingType = BindingType::BindKey) = 0;
+	void set_keymap_hints();
+
+	/// The name of the "main" STFL widget, i.e. the one that should be focused
+	/// by default.
+	virtual std::string main_widget() const = 0;
+
+	void set_title(const std::string& title);
 
 	void start_bookmark_qna(const std::string& default_title,
 		const std::string& default_url,
@@ -113,8 +143,9 @@ protected:
 	void handle_parsed_command(const Command& command);
 
 	bool handle_list_operations(ListWidget& list, Operation op);
+	bool handle_textview_operations(TextviewWidget& textview, Operation op);
 
-	View* v;
+	View& v;
 	ConfigContainer* cfg;
 	Stfl::Form f;
 	bool do_redraw;
@@ -135,8 +166,11 @@ private:
 	void handle_dumpconfig(const std::vector<std::string>& args);
 	void handle_exec(const std::vector<std::string>& args);
 
+	LineView head_line;
+	LineView msg_line;
+	LineView qna_prompt_line;
 	std::vector<QnaPair> qna_prompts;
-	Operation finish_operation;
+	QnaFinishAction qna_finish_operation;
 	History* qna_history;
 	std::shared_ptr<FormAction> parent_formaction;
 };
