@@ -2,7 +2,7 @@
 #define NEWSBOAT_URLVIEWFORMACTION_H_
 
 #include "formaction.h"
-#include "htmlrenderer.h"
+#include "links.h"
 #include "listwidget.h"
 
 namespace newsboat {
@@ -16,7 +16,7 @@ public:
 	~UrlViewFormAction() override = default;
 	void prepare() override;
 	void init() override;
-	const std::vector<KeyMapHintEntry>& get_keymap_hint() const override;
+	std::vector<KeyMapHintEntry> get_keymap_hint() const override;
 	void set_links(const Links& l)
 	{
 		links = l;
