@@ -1,9 +1,12 @@
-#include <cstring>
-#include <errno.h>
+#include <algorithm>
+#include <cstddef>
 #include <iostream>
 #include <ncurses.h>
 #include <sstream>
+#include <string>
 #include <sys/utsname.h>
+#include <utility>
+#include <vector>
 
 #include "cache.h"
 #include "cliargsparser.h"
@@ -50,38 +53,38 @@ void print_usage(const std::string& argv0, const ConfigPaths& configpaths)
 		{
 			'u',
 			"url-file",
-			_s("<urlfile>"),
-			_s("read RSS feed URLs from <urlfile>")
+			_s("<file>"),
+			_s("read RSS feed URLs from <file>")
 		},
 		{
 			'c',
 			"cache-file",
-			_s("<cachefile>"),
-			_s("use <cachefile> as cache file")
+			_s("<file>"),
+			_s("use <file> as cache file")
 		},
 		{
 			'C',
 			"config-file",
-			_s("<configfile>"),
-			_s("read configuration from <configfile>")
+			_s("<file>"),
+			_s("read configuration from <file>")
 		},
 		{
 			'-',
 			"queue-file",
-			_s("<queuefile>"),
-			_s("use <queuefile> as podcast queue file")
+			_s("<file>"),
+			_s("use <file> as podcast queue file")
 		},
 		{
 			'-',
 			"search-history-file",
-			_s("<searchfile>"),
-			_s("save the input history of the search to <searchfile>")
+			_s("<file>"),
+			_s("save the input history of the search to <file>")
 		},
 		{
 			'-',
 			"cmdline-history-file",
-			_s("<cmdlinefile>"),
-			_s("save the input history of the command line to <cmdlinefile>")
+			_s("<file>"),
+			_s("save the input history of the command line to <file>")
 		},
 		{'X', "vacuum", "", _s("compact the cache")},
 		{
@@ -102,8 +105,8 @@ void print_usage(const std::string& argv0, const ConfigPaths& configpaths)
 		{
 			'd',
 			"log-file",
-			_s("<logfile>"),
-			_s("use <logfile> as output log file")
+			_s("<file>"),
+			_s("use <file> as output log file")
 		},
 		{
 			'E',
@@ -121,7 +124,8 @@ void print_usage(const std::string& argv0, const ConfigPaths& configpaths)
 		{'-', "cleanup", "", _s("remove unreferenced items from cache")}
 	};
 
-	std::stringstream ss;
+	std::vector<std::pair<std::string, std::string>> helpLines;
+	std::size_t maxLength = 0;
 	for (const auto& a : args) {
 		std::string longcolumn;
 		if (a.name != '-') {
@@ -133,15 +137,17 @@ void print_usage(const std::string& argv0, const ConfigPaths& configpaths)
 		}
 		longcolumn += "--" + a.longname;
 		longcolumn += a.params.size() > 0 ? "=" + a.params : "";
-		ss << "\t" << longcolumn;
-		for (unsigned int j = 0; j < utils::gentabs(longcolumn); j++) {
-			ss << "\t";
-		}
-		ss << a.desc << std::endl;
-	}
-	std::cout << ss.str();
 
-	std::cout << '\n';
+		maxLength = std::max(maxLength, longcolumn.length());
+		helpLines.push_back({longcolumn, a.desc});
+	}
+	for (const auto& helpLine : helpLines) {
+		std::cout << std::string(8, ' ') << helpLine.first;
+		const auto padding = maxLength - helpLine.first.length();
+		std::cout << std::string(2 + padding, ' ') << helpLine.second;
+		std::cout << std::endl;
+	}
+	std::cout << std::endl;
 
 	std::cout << _("Files:") << '\n';
 	// i18n: This is printed out by --help before the path to the config file
@@ -188,11 +194,11 @@ void print_version(const std::string& argv0, unsigned int level)
 			<< PROGRAM_URL << std::endl;
 		ss << "Copyright (C) 2006-2015 Andreas Krennmair"
 			<< std::endl;
-		ss << "Copyright (C) 2015-2024 Alexander Batischev"
+		ss << "Copyright (C) 2015-2025 Alexander Batischev"
 			<< std::endl;
 		ss << "Copyright (C) 2006-2017 Newsbeuter contributors"
 			<< std::endl;
-		ss << "Copyright (C) 2017-2024 Newsboat contributors"
+		ss << "Copyright (C) 2017-2025 Newsboat contributors"
 			<< std::endl;
 		ss << std::endl;
 
@@ -263,7 +269,7 @@ int main(int argc, char* argv[])
 	}
 
 	Controller c(configpaths);
-	newsboat::View v(&c);
+	newsboat::View v(c);
 	c.set_view(&v);
 	CliArgsParser args(argc, argv);
 
