@@ -69,20 +69,22 @@
 //! beginning of the program.
 use backtrace::Backtrace;
 use std::io::{self, stderr, BufWriter, Write};
-use std::panic::{self, PanicInfo};
+use std::panic;
+
+use std::panic::PanicHookInfo;
 
 /// Sets up a panic hook with a user-friendly message.
 ///
 /// See module description for details.
 pub fn setup() {
     if ::std::env::var("RUST_BACKTRACE").is_err() {
-        panic::set_hook(Box::new(move |panic_info: &PanicInfo| {
+        panic::set_hook(Box::new(move |panic_info: &PanicHookInfo| {
             print_panic_msg(panic_info).expect("An error occurred while preparing a crash report");
         }));
     }
 }
 
-fn print_panic_msg(panic_info: &PanicInfo) -> io::Result<()> {
+fn print_panic_msg(panic_info: &PanicHookInfo) -> io::Result<()> {
     // Locking the handle to make sure all the messages are printed out in one chunk.
     let stderr = stderr();
     let handle = stderr.lock();
@@ -125,7 +127,7 @@ fn print_panic_msg(panic_info: &PanicInfo) -> io::Result<()> {
     Ok(())
 }
 
-fn get_error_message(panic_info: &PanicInfo) -> String {
+fn get_error_message(panic_info: &PanicHookInfo) -> String {
     let payload = panic_info.payload().downcast_ref::<&str>();
     if let Some(payload) = payload {
         format!("Message: {}", &payload)
@@ -134,7 +136,7 @@ fn get_error_message(panic_info: &PanicInfo) -> String {
     }
 }
 
-fn get_location(panic_info: &PanicInfo) -> String {
+fn get_location(panic_info: &PanicHookInfo) -> String {
     match panic_info.location() {
         Some(location) => format!("Crash location: {}:{}", location.file(), location.line()),
         None => String::from("Crash location unknown"),
