@@ -1,4 +1,4 @@
-use crate::htmlrenderer;
+use crate::links;
 use crate::logger::{self, Level};
 use libc::{
     c_char, c_int, c_ulong, c_void, close, execvp, exit, fork, size_t, waitpid, E2BIG, EILSEQ,
@@ -13,6 +13,7 @@ use std::os::unix::fs::DirBuilderExt;
 use std::path::{Path, PathBuf};
 use std::process::{Command, Stdio};
 use std::ptr;
+use unicode_segmentation::UnicodeSegmentation;
 use unicode_width::{UnicodeWidthChar, UnicodeWidthStr};
 use url::Url;
 
@@ -26,7 +27,7 @@ pub fn consolidate_whitespace(input: String) -> String {
 
     if let Some(found) = found {
         let (leading, rest) = input.split_at(found);
-        let lastchar = input.chars().rev().next().unwrap();
+        let lastchar = input.chars().next_back().unwrap();
 
         result.push_str(leading);
 
@@ -258,14 +259,14 @@ pub fn strwidth_stfl(mut s: &str) -> usize {
 pub fn substr_with_width(string: &str, max_width: usize) -> String {
     let mut result = String::new();
     let mut width = 0;
-    for c in string.chars() {
+    for g in string.graphemes(true) {
         // Control chars count as width 0
-        let w = UnicodeWidthChar::width(c).unwrap_or(0);
+        let w = UnicodeWidthStr::width(g);
         if width + w > max_width {
             break;
         }
         width += w;
-        result.push(c);
+        result.push_str(g);
     }
     result
 }
@@ -330,7 +331,7 @@ pub fn remove_soft_hyphens(text: &mut String) {
 ///
 /// 2. figuring out the `LinkType` for a particular enclosure, given its MIME type
 ///    (`utils::podcast_mime_to_link_type`).
-type MimeMatcher = (fn(&str) -> bool, htmlrenderer::LinkType);
+type MimeMatcher = (fn(&str) -> bool, links::LinkType);
 const PODCAST_MIME_TO_LINKTYPE: [MimeMatcher; 2] = [
     (
         |mime| {
@@ -339,12 +340,9 @@ const PODCAST_MIME_TO_LINKTYPE: [MimeMatcher; 2] = [
             // https://tools.ietf.org/html/rfc5334#section-10.1
             mime.starts_with("audio/") || mime == "application/ogg"
         },
-        htmlrenderer::LinkType::Audio,
-    ),
-    (
-        |mime| mime.starts_with("video/"),
-        htmlrenderer::LinkType::Video,
+        links::LinkType::Audio,
     ),
+    (|mime| mime.starts_with("video/"), links::LinkType::Video),
 ];
 
 /// Returns `true` if given MIME type is considered to be a podcast by Newsboat.
@@ -357,7 +355,7 @@ pub fn is_valid_podcast_type(mimetype: &str) -> bool {
 /// Converts podcast's MIME type into an HtmlRenderer's "link type"
 ///
 /// Returns None if given MIME type is not a podcast type. See `is_valid_podcast_type()`.
-pub fn podcast_mime_to_link_type(mime_type: &str) -> Option<htmlrenderer::LinkType> {
+pub fn podcast_mime_to_link_type(mime_type: &str) -> Option<links::LinkType> {
     PODCAST_MIME_TO_LINKTYPE
         .iter()
         .find_map(|(matcher, link_type)| {
@@ -468,7 +466,7 @@ pub fn run_command(cmd: &str, param: &str) {
     }
 }
 
-pub fn run_program(cmd_with_args: &[&str], input: &str) -> String {
+pub fn run_program(cmd_with_args: &[&str], input: String) -> String {
     if cmd_with_args.is_empty() {
         return String::new();
     }
@@ -485,19 +483,21 @@ pub fn run_program(cmd_with_args: &[&str], input: &str) -> String {
                 "utils::run_program: spawning a child for \"{:?}\" \
                  with input \"{}\" failed: {}",
                 cmd_with_args,
-                input,
+                &input,
                 error
             );
         })
         .and_then(|mut child| {
-            if let Some(stdin) = child.stdin.as_mut() {
-                if let Err(error) = stdin.write_all(input.as_bytes()) {
-                    log!(
-                        Level::Debug,
-                        "utils::run_program: failed to write to child's stdin: {}",
-                        error
-                    );
-                }
+            if let Some(mut stdin) = child.stdin.take() {
+                std::thread::spawn(move || {
+                    if let Err(error) = stdin.write_all(input.as_bytes()) {
+                        log!(
+                            Level::Debug,
+                            "utils::run_program: failed to write to child's stdin: {}",
+                            error
+                        );
+                    }
+                });
             }
 
             child
@@ -552,9 +552,13 @@ pub fn make_title(rs_str: String) -> String {
 
     // Un-escape any percent-encoding, e.g. "It%27s%202017%21" -> "It's
     // 2017!"
-    match unescape_url(result) {
-        None => String::new(),
-        Some(f) => f,
+    let result = unescape_url(result).unwrap_or_default();
+
+    // If it contains only digits, assume it's an id, not a proper title
+    if result.chars().all(|c| c.is_ascii_digit()) {
+        String::new()
+    } else {
+        result
     }
 }
 
@@ -640,19 +644,6 @@ pub fn strnaturalcmp(a: &str, b: &str) -> std::cmp::Ordering {
     natord::compare(a, b)
 }
 
-/// Calculate the number of padding tabs when formatting columns
-///
-/// The number of tabs will be adjusted by the width of the given string.  Usually, a column will
-/// consist of 4 tabs, 8 characters each.  Each column will consist of at least one tab.
-pub fn gentabs(string: &str) -> usize {
-    let tabcount = strwidth(string) / 8;
-    if tabcount >= 4 {
-        1
-    } else {
-        4 - tabcount
-    }
-}
-
 /// Recursively create directories if missing and set permissions accordingly.
 pub fn mkdir_parents<R: AsRef<Path>>(p: &R, mode: u32) -> io::Result<()> {
     DirBuilder::new()
@@ -951,7 +942,7 @@ pub fn convert_text(text: &[u8], tocode: &str, fromcode: &str) -> Vec<u8> {
     }
 
     unsafe {
-        let mut outbuf: [u8; 16] = [0; 16];
+        let mut outbuf = vec![0u8; 65536];
         let mut outbufp = outbuf.as_mut_ptr() as *mut c_char;
         let mut outbytesleft = outbuf.len();
 
@@ -1046,6 +1037,33 @@ pub fn locale_to_utf8(text: &[u8]) -> String {
     String::from_utf8(converted).expect("convert_text() returned a non-UTF-8 string")
 }
 
+/// Parses a string in the form `author@example.com (Example Author)`
+/// into a pair of (author, email).
+/// If the pattern cannot be matched or the name is empty, the input
+/// is returned completely as author with empty email.
+///
+/// Invalid data (outside of utf-8) is replaced with Unicode replacement characters.
+pub fn parse_rss_author_email(text: &[u8]) -> (String, String) {
+    let re = regex::bytes::Regex::new(r#"^([^ ]+@[^ ]+)\s+\((.+)\)$"#)
+        .expect("Programming error in hardcoded regex");
+
+    if let Some(m) = re.captures(text) {
+        let (_, [email, name]) = m.extract();
+
+        // Unwrapping is safe because the regex only matches valid (utf-8) unicode
+        let (name, email) = (
+            String::from_utf8(name.into()).unwrap().trim().to_owned(),
+            String::from_utf8(email.into()).unwrap().trim().to_owned(),
+        );
+
+        if !name.is_empty() {
+            return (name, email);
+        }
+    }
+
+    (String::from_utf8_lossy(text).into_owned(), "".into())
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -1210,23 +1228,23 @@ mod tests {
     fn t_tokenize_quoted_interprets_double_backslash_as_literal_backslash() {
         assert_eq!(tokenize_quoted(r#""""#, ""), vec![""]);
 
-        assert_eq!(tokenize_quoted(r#""\\""#, ""), vec![r#"\"#]);
+        assert_eq!(tokenize_quoted(r#""\\""#, ""), vec![r"\"]);
 
         assert_eq!(tokenize_quoted(r##""#\\""##, ""), vec!["#\\"]);
 
         assert_eq!(tokenize_quoted(r#""'#\\'""#, ""), vec!["'#\\'"]);
 
-        assert_eq!(tokenize_quoted(r#""'#\\ \\'""#, ""), vec![r#"'#\ \'"#]);
+        assert_eq!(tokenize_quoted(r#""'#\\ \\'""#, ""), vec![r"'#\ \'"]);
 
-        assert_eq!(tokenize_quoted("\"\\\\\\\\", ""), vec![r#"\\"#]);
+        assert_eq!(tokenize_quoted("\"\\\\\\\\", ""), vec![r"\\"]);
 
-        assert_eq!(tokenize_quoted("\"\\\\\\\\\\\\", ""), vec![r#"\\\"#]);
+        assert_eq!(tokenize_quoted("\"\\\\\\\\\\\\", ""), vec![r"\\\"]);
 
-        assert_eq!(tokenize_quoted("\"\\\\\\\\\"", ""), vec![r#"\\"#]);
+        assert_eq!(tokenize_quoted("\"\\\\\\\\\"", ""), vec![r"\\"]);
 
-        assert_eq!(tokenize_quoted("\"\\\\\\\\\\\\\"", ""), vec![r#"\\\"#]);
+        assert_eq!(tokenize_quoted("\"\\\\\\\\\\\\\"", ""), vec![r"\\\"]);
 
-        assert_eq!(tokenize_quoted(r#""\\bgit\\b""#, ""), vec![r#"\bgit\b"#]);
+        assert_eq!(tokenize_quoted(r#""\\bgit\\b""#, ""), vec![r"\bgit\b"]);
 
         assert_eq!(
             tokenize_quoted(
@@ -1235,7 +1253,7 @@ mod tests {
             ),
             vec![
                 "browser",
-                r#"/Applications/Google\ Chrome.app/Contents/MacOS/Google\ Chrome --app %u"#
+                r"/Applications/Google\ Chrome.app/Contents/MacOS/Google\ Chrome --app %u"
             ]
         );
     }
@@ -1281,7 +1299,7 @@ mod tests {
     #[test]
     fn t_tokenize_quoted_ignores_escaped_pound_sign_start_of_token() {
         assert_eq!(
-            tokenize_quoted(r#"one \# two three # ???"#, " "),
+            tokenize_quoted(r"one \# two three # ???", " "),
             vec!["one", "\\#", "two", "three"]
         );
     }
@@ -1423,7 +1441,7 @@ mod tests {
         assert_eq!(strwidth(""), 0);
         assert_eq!(strwidth("xx"), 2);
         assert_eq!(strwidth("\u{F91F}"), 2);
-        assert_eq!(strwidth("\u{0007}"), 0);
+        assert_eq!(strwidth("\u{0007}"), 1);
     }
 
     #[test]
@@ -1435,7 +1453,7 @@ mod tests {
         assert_eq!(strwidth_stfl("x<>y<>z"), 5);
         assert_eq!(strwidth_stfl("x<>hi>x"), 6);
         assert_eq!(strwidth_stfl("\u{F91F}"), 2);
-        assert_eq!(strwidth_stfl("\u{0007}"), 0);
+        assert_eq!(strwidth_stfl("\u{0007}"), 1);
         assert_eq!(strwidth_stfl("<a"), 0); // #415
         assert_eq!(strwidth_stfl("a"), 1);
         assert_eq!(strwidth_stfl("abc<tag>def"), 6);
@@ -1493,7 +1511,16 @@ mod tests {
 
     #[test]
     fn t_substr_with_width_max_width_non_printable() {
-        assert_eq!(substr_with_width("\x01\x02abc", 1), "\x01\x02a");
+        assert_eq!(substr_with_width("\x01\x02abc", 1), "\x01");
+    }
+
+    #[test]
+    fn t_substr_with_width_keeps_graphemes_complete() {
+        let input = "a⚛️b"; // Symbol unicode: "\u{269B}\u{FE0F}"
+        assert_eq!(substr_with_width(input, 1), "a");
+        assert_eq!(substr_with_width(input, 2), "a");
+        assert_eq!(substr_with_width(input, 3), "a⚛️");
+        assert_eq!(substr_with_width(input, 4), "a⚛️b");
     }
 
     #[test]
@@ -1573,7 +1600,7 @@ mod tests {
 
     #[test]
     fn t_podcast_mime_to_link_type() {
-        use crate::htmlrenderer::LinkType::*;
+        use crate::links::LinkType::*;
 
         assert_eq!(podcast_mime_to_link_type("audio/mpeg"), Some(Audio));
         assert_eq!(podcast_mime_to_link_type("audio/mp3"), Some(Audio));
@@ -1701,10 +1728,10 @@ mod tests {
     #[test]
     fn t_run_program() {
         let input1 = "this is a multine-line\ntest string";
-        assert_eq!(run_program(&["cat"], input1), input1);
+        assert_eq!(run_program(&["cat"], input1.to_owned()), input1);
 
         assert_eq!(
-            run_program(&["echo", "-n", "hello world"], ""),
+            run_program(&["echo", "-n", "hello world"], String::new()),
             "hello world"
         );
     }
@@ -1973,12 +2000,12 @@ mod tests {
         assert_eq!(strip_comments(&input), expected);
 
         // Escaped backtick inside backticks is not treated as closing
-        let expected = r#"some `other \` tricky # test` hehe"#;
+        let expected = r"some `other \` tricky # test` hehe";
         let input = expected.to_owned() + "#here goescomment";
         assert_eq!(strip_comments(&input), expected);
 
         // Ignores escaped # characters (\\#)
-        let expected = r#"one two \# three four"#;
+        let expected = r"one two \# three four";
         let input = expected.to_owned() + "# and a comment";
         assert_eq!(strip_comments(&input), expected);
     }
@@ -2270,27 +2297,6 @@ mod tests {
         );
     }
 
-    #[test]
-    fn t_gentabs() {
-        assert_eq!(gentabs(""), 4);
-        assert_eq!(gentabs("a"), 4);
-        assert_eq!(gentabs("aa"), 4);
-        assert_eq!(gentabs("aaa"), 4);
-        assert_eq!(gentabs("aaaa"), 4);
-        assert_eq!(gentabs("aaaaa"), 4);
-        assert_eq!(gentabs("aaaaaa"), 4);
-        assert_eq!(gentabs("aaaaaaa"), 4);
-        assert_eq!(gentabs("aaaaaaaa"), 3);
-        assert_eq!(gentabs(&"a".repeat(8)), 3);
-        assert_eq!(gentabs(&"a".repeat(9)), 3);
-        assert_eq!(gentabs(&"a".repeat(15)), 3);
-        assert_eq!(gentabs(&"a".repeat(16)), 2);
-        assert_eq!(gentabs(&"a".repeat(20)), 2);
-        assert_eq!(gentabs(&"a".repeat(24)), 1);
-        assert_eq!(gentabs(&"a".repeat(32)), 1);
-        assert_eq!(gentabs(&"a".repeat(100)), 1);
-    }
-
     #[test]
     fn t_run_non_interactively() {
         let result = run_non_interactively("echo true", "test");
@@ -2397,4 +2403,67 @@ mod tests {
             "query:name:age between 1:10"
         );
     }
+
+    #[test]
+    fn t_parse_rss_author_email() {
+        assert_eq!(
+            parse_rss_author_email(b"Example Author"),
+            ("Example Author".into(), "".into())
+        );
+
+        assert_eq!(
+            parse_rss_author_email(b"author@example.com (Example Author)"),
+            ("Example Author".into(), "author@example.com".into())
+        );
+
+        assert_eq!(
+            parse_rss_author_email(b"author@example.com  \t  (Example Author)"),
+            ("Example Author".into(), "author@example.com".into())
+        );
+
+        assert_eq!(
+            parse_rss_author_email(b"Wrong Order (author@example.com)"),
+            ("Wrong Order (author@example.com)".into(), "".into())
+        );
+
+        assert_eq!(
+            parse_rss_author_email(b"author@example.com (    )"),
+            ("author@example.com (    )".into(), "".into())
+        );
+
+        assert_eq!(
+            parse_rss_author_email(b"author@example.com Example Author"),
+            ("author@example.com Example Author".into(), "".into())
+        );
+
+        assert_eq!(
+            parse_rss_author_email(b"A Name (with extra info)"),
+            ("A Name (with extra info)".into(), "".into())
+        );
+
+        assert_eq!(
+            parse_rss_author_email(b"author@example.com (email) extra info"),
+            ("author@example.com (email) extra info".into(), "".into())
+        );
+    }
+
+    #[test]
+    fn t_parse_rss_author_email_invalid_unicode() {
+        // Inject invalid 0x80 byte to check that invalid unicode is not an issue
+        assert_eq!(
+            parse_rss_author_email(b"author\x80@example.com (Example author)"),
+            (
+                "author\u{fffd}@example.com (Example author)".into(),
+                "".into()
+            )
+        );
+
+        assert_eq!(
+            parse_rss_author_email(b"author@example.com (Example \x80 author)"),
+            (
+                "author@example.com (Example \u{fffd} author)".into(),
+                "".into()
+            )
+        );
+    }
 }
