@@ -85,6 +85,12 @@ ConfigContainer::ConfigContainer()
 	{
 		"feedhq-url",
 		ConfigData("https://feedhq.org/", ConfigDataType::STR)},
+	{"feedbin-url", ConfigData("https://api.feedbin.com", ConfigDataType::STR)},
+	{"feedbin-login", ConfigData("", ConfigDataType::STR)},
+	{"feedbin-password", ConfigData("", ConfigDataType::STR)},
+	{"feedbin-passwordfile", ConfigData("", ConfigDataType::PATH)},
+	{"feedbin-passwordeval", ConfigData("", ConfigDataType::STR)},
+	{"feedbin-flag-star", ConfigData("", ConfigDataType::STR)},
 	{"freshrss-flag-star", ConfigData("", ConfigDataType::STR)},
 	{"freshrss-login", ConfigData("", ConfigDataType::STR)},
 	{"freshrss-min-items", ConfigData("20", ConfigDataType::INT)},
@@ -186,7 +192,7 @@ ConfigContainer::ConfigContainer()
 		ConfigData("no", ConfigDataType::BOOL)},
 	{
 		"podlist-format",
-		ConfigData( "%4i [%6dMB/%6tMB] [%5p %%] [%12K] %-20S %u -> %F", ConfigDataType::STR)},
+		ConfigData( _("%4i [%6dMB/%6tMB] [%5p %%] [%12K] %-20S %u -> %F"), ConfigDataType::STR)},
 	{
 		"prepopulate-query-feeds",
 		ConfigData("false", ConfigDataType::BOOL)},
@@ -261,11 +267,15 @@ ConfigContainer::ConfigContainer()
 	{"ocnews-passwordeval", ConfigData("", ConfigDataType::STR)},
 	{"ocnews-flag-star", ConfigData("", ConfigDataType::STR)},
 	{"ocnews-url", ConfigData("", ConfigDataType::STR)},
+	{"miniflux-flag-star", ConfigData("", ConfigDataType::STR)},
 	{"miniflux-login", ConfigData("", ConfigDataType::STR)},
 	{"miniflux-min-items", ConfigData("100", ConfigDataType::INT)},
 	{"miniflux-password", ConfigData("", ConfigDataType::STR)},
 	{"miniflux-passwordfile", ConfigData("", ConfigDataType::PATH)},
 	{"miniflux-passwordeval", ConfigData("", ConfigDataType::STR)},
+	{
+		"miniflux-show-special-feeds",
+		ConfigData("yes", ConfigDataType::BOOL)},
 	{"miniflux-token", ConfigData("", ConfigDataType::STR)},
 	{"miniflux-tokenfile", ConfigData("", ConfigDataType::PATH)},
 	{"miniflux-tokeneval", ConfigData("", ConfigDataType::STR)},
@@ -279,6 +289,7 @@ ConfigContainer::ConfigContainer()
 			"ttrss",
 			"newsblur",
 			"feedhq",
+			"feedbin",
 			"freshrss",
 			"ocnews",
 			"miniflux",
@@ -335,10 +346,7 @@ ConfigContainer::ConfigContainer()
 {
 }
 
-ConfigContainer::~ConfigContainer()
-{
-	std::lock_guard<std::recursive_mutex> guard(config_data_mtx);
-}
+ConfigContainer::~ConfigContainer() = default;
 
 void ConfigContainer::register_commands(ConfigParser& cfgparser)
 {
@@ -447,7 +455,8 @@ bool ConfigContainer::get_configvalue_as_bool(const std::string& key) const
 	return false;
 }
 
-void ConfigContainer::set_configvalue(const std::string& key,
+nonstd::expected<void, std::string> ConfigContainer::set_configvalue(
+	const std::string& key,
 	const std::string& value)
 {
 	LOG(Level::DEBUG,
@@ -455,7 +464,14 @@ void ConfigContainer::set_configvalue(const std::string& key,
 		key,
 		value);
 	std::lock_guard<std::recursive_mutex> guard(config_data_mtx);
-	config_data[key].set_value(value);
+	auto config_option = config_data.find(key);
+	if (config_option != config_data.end()) {
+		return config_option->second.set_value(value);
+	} else {
+		return nonstd::make_unexpected(strprintf::fmt(
+					_("unknown config option: %s"),
+					key));
+	}
 }
 
 void ConfigContainer::reset_to_default(const std::string& key)
