@@ -7,7 +7,6 @@
 #include <ctime>
 #include <curl/curl.h>
 #include <fstream>
-#include <functional>
 #include <iostream>
 #include <langinfo.h>
 #include <libgen.h>
@@ -16,7 +15,6 @@
 #include <libxml/xmlsave.h>
 #include <libxml/xmlversion.h>
 #include <memory>
-#include <mutex>
 #include <pwd.h>
 #include <signal.h>
 #include <sys/stat.h>
@@ -53,6 +51,7 @@
 #include "ocnewsurlreader.h"
 #include "oldreaderapi.h"
 #include "oldreaderurlreader.h"
+#include "opml.h"
 #include "opmlurlreader.h"
 #include "regexmanager.h"
 #include "remoteapi.h"
@@ -82,22 +81,12 @@ void ignore_signal(int sig)
 
 Controller::Controller(ConfigPaths& configpaths)
 	: v(0)
-	, urlcfg(0)
-	, rsscache(0)
 	, refresh_on_start(false)
-	, api(0)
 	, configpaths(configpaths)
 	, queueManager(&cfg, configpaths.queue_file())
 {
 }
 
-Controller::~Controller()
-{
-	delete rsscache;
-	delete urlcfg;
-	delete api;
-}
-
 void Controller::set_view(View* vv)
 {
 	v = vv;
@@ -169,6 +158,7 @@ int Controller::run(const CliArgsParser& args)
 	colorman.register_commands(cfgparser);
 
 	KeyMap keys(KM_NEWSBOAT);
+	cfgparser.register_handler("bind", keys);
 	cfgparser.register_handler("bind-key", keys);
 	cfgparser.register_handler("unbind-key", keys);
 	cfgparser.register_handler("macro", keys);
@@ -228,7 +218,7 @@ int Controller::run(const CliArgsParser& args)
 		std::cout.flush();
 	}
 	try {
-		rsscache = new Cache(configpaths.cache_file(), &cfg);
+		rsscache = std::make_unique<Cache>(configpaths.cache_file(), &cfg);
 	} catch (const DbException& e) {
 		std::cerr << strprintf::fmt(
 				_("Error: opening the cache file `%s' "
@@ -251,20 +241,20 @@ int Controller::run(const CliArgsParser& args)
 		std::cout << _("done.") << std::endl;
 	}
 
-	reloader = std::make_unique<Reloader>(this, rsscache, cfg);
+	reloader = std::make_unique<Reloader>(*this, *rsscache, cfg);
 
 	std::string type = cfg.get_configvalue("urls-source");
 	if (type == "local") {
-		urlcfg = new FileUrlReader(configpaths.url_file());
+		urlcfg = std::make_unique<FileUrlReader>(configpaths.url_file());
 	} else if (type == "opml") {
-		urlcfg = new OpmlUrlReader(cfg);
+		urlcfg = std::make_unique<OpmlUrlReader>(cfg);
 	} else if (type == "oldreader") {
-		api = new OldReaderApi(cfg);
-		urlcfg = new OldReaderUrlReader(
-			&cfg, configpaths.url_file(), api);
+		api = std::make_unique<OldReaderApi>(cfg);
+		urlcfg = std::make_unique<OldReaderUrlReader>(
+				&cfg, configpaths.url_file(), api.get());
 	} else if (type == "ttrss") {
-		api = new TtRssApi(cfg);
-		urlcfg = new TtRssUrlReader(configpaths.url_file(), api);
+		api = std::make_unique<TtRssApi>(cfg);
+		urlcfg = std::make_unique<TtRssUrlReader>(configpaths.url_file(), api.get());
 	} else if (type == "newsblur") {
 		const auto cookies = cfg.get_configvalue("cookie-cache");
 		if (cookies.empty()) {
@@ -282,11 +272,11 @@ int Controller::run(const CliArgsParser& args)
 			return EXIT_FAILURE;
 		}
 
-		api = new NewsBlurApi(cfg);
-		urlcfg = new NewsBlurUrlReader(configpaths.url_file(), api);
+		api = std::make_unique<NewsBlurApi>(cfg);
+		urlcfg = std::make_unique<NewsBlurUrlReader>(configpaths.url_file(), api.get());
 	} else if (type == "feedhq") {
-		api = new FeedHqApi(cfg);
-		urlcfg = new FeedHqUrlReader(&cfg, configpaths.url_file(), api);
+		api = std::make_unique<FeedHqApi>(cfg);
+		urlcfg = std::make_unique<FeedHqUrlReader>(&cfg, configpaths.url_file(), api.get());
 	} else if (type == "feedbin") {
 		const std::string user = cfg.get_configvalue("feedbin-login");
 		const std::string pass = cfg.get_configvalue("feedbin-password");
@@ -302,8 +292,8 @@ int Controller::run(const CliArgsParser& args)
 			return EXIT_FAILURE;
 		}
 
-		api = new FeedbinApi(cfg);
-		urlcfg = new FeedbinUrlReader(configpaths.url_file(), api);
+		api = std::make_unique<FeedbinApi>(cfg);
+		urlcfg = std::make_unique<FeedbinUrlReader>(configpaths.url_file(), api.get());
 	} else if (type == "freshrss") {
 		const auto freshrss_url = cfg.get_configvalue("freshrss-url");
 		if (freshrss_url.empty()) {
@@ -326,11 +316,11 @@ int Controller::run(const CliArgsParser& args)
 			return EXIT_FAILURE;
 		}
 
-		api = new FreshRssApi(cfg);
-		urlcfg = new FreshRssUrlReader(&cfg, configpaths.url_file(), api);
+		api = std::make_unique<FreshRssApi>(cfg);
+		urlcfg = std::make_unique<FreshRssUrlReader>(&cfg, configpaths.url_file(), api.get());
 	} else if (type == "ocnews") {
-		api = new OcNewsApi(cfg);
-		urlcfg = new OcNewsUrlReader(configpaths.url_file(), api);
+		api = std::make_unique<OcNewsApi>(cfg);
+		urlcfg = std::make_unique<OcNewsUrlReader>(configpaths.url_file(), api.get());
 	} else if (type == "miniflux") {
 		const auto miniflux_url = cfg.get_configvalue("miniflux-url");
 		if (miniflux_url.empty()) {
@@ -356,8 +346,8 @@ int Controller::run(const CliArgsParser& args)
 			return EXIT_FAILURE;
 		}
 
-		api = new MinifluxApi(cfg);
-		urlcfg = new MinifluxUrlReader(&cfg, configpaths.url_file(), api);
+		api = std::make_unique<MinifluxApi>(cfg);
+		urlcfg = std::make_unique<MinifluxUrlReader>(&cfg, configpaths.url_file(), api.get());
 	} else if (type == "inoreader") {
 		const auto all_set = !cfg.get_configvalue("inoreader-app-id").empty()
 			&& !cfg.get_configvalue("inoreader-app-key").empty();
@@ -367,8 +357,8 @@ int Controller::run(const CliArgsParser& args)
 			return EXIT_FAILURE;
 		}
 
-		api = new InoreaderApi(cfg);
-		urlcfg = new InoreaderUrlReader(&cfg, configpaths.url_file(), api);
+		api = std::make_unique<InoreaderApi>(cfg);
+		urlcfg = std::make_unique<InoreaderUrlReader>(&cfg, configpaths.url_file(), api.get());
 	} else {
 		std::cerr << strprintf::fmt(_("ERROR: Unknown urls-source `%s'"),
 				type) << std::endl;
@@ -382,7 +372,7 @@ int Controller::run(const CliArgsParser& args)
 	}
 	if (api) {
 		if (!api->authenticate()) {
-			std::cout << "Authentication failed." << std::endl;
+			std::cerr << _("Authentication failed.") << std::endl;
 			return EXIT_FAILURE;
 		}
 	}
@@ -555,7 +545,7 @@ int Controller::run(const CliArgsParser& args)
 	v->set_config_container(&cfg);
 	v->set_keymap(&keys);
 	v->set_tags(tags);
-	v->set_cache(rsscache);
+	v->set_cache(rsscache.get());
 
 	const auto cmds_to_execute = args.cmds_to_execute();
 	if (cmds_to_execute.size() >= 1) {
@@ -682,7 +672,7 @@ void Controller::mark_all_read(unsigned int pos)
 			}
 			api->mark_articles_read(item_guids);
 		}
-		rsscache->mark_all_read(feed);
+		rsscache->mark_all_read(*feed);
 	} else {
 		rsscache->mark_all_read(feed->rssurl());
 		if (api) {
@@ -704,29 +694,27 @@ void Controller::mark_all_read(const std::vector<std::string>& item_guids)
 	}
 }
 
-void Controller::replace_feed(std::shared_ptr<RssFeed> oldfeed,
-	std::shared_ptr<RssFeed> newfeed,
-	unsigned int pos,
+void Controller::replace_feed(RssFeed& oldfeed, RssFeed& newfeed, unsigned int pos,
 	bool unattended)
 {
 	LOG(Level::DEBUG, "Controller::replace_feed: saving");
 	rsscache->externalize_rssfeed(
-		newfeed, ign.matches_resetunread(newfeed->rssurl()));
+		newfeed, ign.matches_resetunread(newfeed.rssurl()));
 	LOG(Level::DEBUG,
 		"Controller::replace_feed: after externalize_rssfeed");
 
 	bool ignore_disp = (cfg.get_configvalue("ignore-mode") == "display");
 	std::shared_ptr<RssFeed> feed = rsscache->internalize_rssfeed(
-			oldfeed->rssurl(), ignore_disp ? &ign : nullptr);
+			oldfeed.rssurl(), ignore_disp ? &ign : nullptr);
 	LOG(Level::DEBUG,
 		"Controller::replace_feed: after internalize_rssfeed");
 
-	feed->set_tags(urlcfg->get_tags(oldfeed->rssurl()));
-	feed->set_order(oldfeed->get_order());
+	feed->set_tags(urlcfg->get_tags(oldfeed.rssurl()));
+	feed->set_order(oldfeed.get_order());
 	feedcontainer.replace_feed(pos, feed);
 
 	if (cfg.get_configvalue_as_bool("podcast-auto-enqueue")) {
-		const auto result = queueManager.autoenqueue(feed);
+		const auto result = queueManager.autoenqueue(*feed);
 		switch (result.status) {
 		case EnqueueStatus::QUEUED_SUCCESSFULLY:
 		case EnqueueStatus::URL_QUEUED_ALREADY:
@@ -745,7 +733,7 @@ void Controller::replace_feed(std::shared_ptr<RssFeed> oldfeed,
 	}
 
 	for (const auto& item : feed->items()) {
-		rsscache->update_rssitem_unread_and_enqueued(item, feed->rssurl());
+		rsscache->update_rssitem_unread_and_enqueued(*item, feed->rssurl());
 	}
 
 	v->notify_itemlist_change(feed);
@@ -823,8 +811,7 @@ std::vector<std::shared_ptr<RssItem>> Controller::search_for_items(
 	return items;
 }
 
-EnqueueResult Controller::enqueue_url(std::shared_ptr<RssItem> item,
-	std::shared_ptr<RssFeed> feed)
+EnqueueResult Controller::enqueue_url(RssItem& item, RssFeed& feed)
 {
 	return queueManager.enqueue_url(item, feed);
 }
@@ -928,7 +915,7 @@ int Controller::execute_commands(const std::vector<std::string>& cmds)
 	return EXIT_SUCCESS;
 }
 
-std::string Controller::write_temporary_item(std::shared_ptr<RssItem> item)
+std::string Controller::write_temporary_item(RssItem& item)
 {
 	char filename[_POSIX_PATH_MAX];
 	char* tmpdir = getenv("TMPDIR");
@@ -952,8 +939,7 @@ std::string Controller::write_temporary_item(std::shared_ptr<RssItem> item)
 	}
 }
 
-void Controller::write_item(std::shared_ptr<RssItem> item,
-	const std::string& filename)
+void Controller::write_item(RssItem& item, const std::string& filename)
 {
 	const std::string save_path = cfg.get_configvalue("save-path");
 	auto spath = save_path.back() == '/' ? save_path : save_path + "/";
@@ -979,7 +965,7 @@ void Controller::write_item(std::shared_ptr<RssItem> item,
 	write_item(item, f);
 }
 
-void Controller::write_item(std::shared_ptr<RssItem> item, std::ostream& ostr)
+void Controller::write_item(RssItem& item, std::ostream& ostr)
 {
 	ostr << item_renderer::to_plain_text(cfg, item) << std::endl;
 }
