@@ -7,10 +7,7 @@
 #include <ncurses.h>
 #include <dirent.h>
 #include <grp.h>
-#include <iomanip>
-#include <iostream>
 #include <pwd.h>
-#include <sstream>
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <unistd.h>
@@ -247,7 +244,7 @@ void DirBrowserFormAction::prepare()
 			add_directory(id_at_position, directory);
 		}
 
-		auto render_line = [this](std::uint32_t line, std::uint32_t width) -> std::string {
+		auto render_line = [this](std::uint32_t line, std::uint32_t width) -> StflRichText {
 			(void)width;
 			return lines[line];
 		};
@@ -295,7 +292,7 @@ void DirBrowserFormAction::init()
 	set_value("filenametext_pos", std::to_string(save_path.length()));
 }
 
-const std::vector<KeyMapHintEntry>& DirBrowserFormAction::get_keymap_hint() const
+std::vector<KeyMapHintEntry> DirBrowserFormAction::get_keymap_hint() const
 {
 	static const std::vector<KeyMapHintEntry> hints = {{OP_QUIT, _("Cancel")},
 		{OP_OPEN, _("Save")}
@@ -330,7 +327,7 @@ void DirBrowserFormAction::add_directory(
 				group,
 				sizestr,
 				formatteddirname);
-		lines.push_back(utils::quote_for_stfl(line));
+		lines.push_back(StflRichText::from_plaintext(line));
 		id_at_position.push_back(file_system::FileSystemEntry{ftype, dirname});
 	}
 }
