@@ -2,15 +2,12 @@
 
 #include <cassert>
 #include <cinttypes>
-#include <exception>
 #include <ncurses.h>
 
 #include "config.h"
 #include "configexception.h"
 #include "controller.h"
-#include "listmovementcontrol.h"
 #include "logger.h"
-#include "matcherexception.h"
 #include "strprintf.h"
 #include "textviewwidget.h"
 #include "utils.h"
@@ -29,7 +26,7 @@ FormAction::FormAction(View& vv, std::string formstr, ConfigContainer* cfg)
 	, head_line(f, "head")
 	, msg_line(f, "msg")
 	, qna_prompt_line(f, "qna_prompt")
-	, finish_operation(OP_NIL)
+	, qna_finish_operation(QnaFinishAction::None)
 	, qna_history(nullptr)
 {
 	if (cfg->get_configvalue_as_bool("show-keymap-hint") == false) {
@@ -82,11 +79,7 @@ void FormAction::draw_form()
 
 std::string FormAction::draw_form_wait_for_event(unsigned int timeout)
 {
-	const char* event = f.run(timeout);
-	if (event == nullptr) {
-		return "";
-	}
-	return std::string(event);
+	return f.run(timeout);
 }
 
 void FormAction::recalculate_widget_dimensions()
@@ -99,7 +92,7 @@ void FormAction::start_cmdline(std::string default_value)
 	std::vector<QnaPair> qna;
 	qna.push_back(QnaPair(":", default_value));
 	v.inside_cmdline(true);
-	this->start_qna(qna, OP_INT_END_CMDLINE, &FormAction::cmdlinehistory);
+	this->start_qna(qna, QnaFinishAction::RunCmdLine, &FormAction::cmdlinehistory);
 }
 
 bool FormAction::process_op(Operation op,
@@ -114,7 +107,7 @@ bool FormAction::process_op(Operation op,
 	case OP_CMDLINE:
 		start_cmdline();
 		break;
-	case OP_INT_SET:
+	case OP_SET:
 		switch (bindingType) {
 		case BindingType::Bind:
 		case BindingType::Macro:
@@ -134,7 +127,7 @@ bool FormAction::process_op(Operation op,
 			return false;
 		case BindingType::BindKey:
 			LOG(Level::WARN,
-				"FormAction::process_op: got OP_INT_SET, but from a bind-key which does not support arguments");
+				"FormAction::process_op: got OP_SET, but from a bind-key which does not support arguments");
 			break;
 		}
 		break;
@@ -251,9 +244,16 @@ void FormAction::handle_set(const std::vector<std::string>& args)
 				args[0],
 				utils::quote_if_necessary(cfg->get_configvalue(args[0]))));
 	} else if (args.size() == 2) {
-		std::string result = ConfigParser::evaluate_backticks(args[1]);
-		utils::trim_end(result);
-		cfg->set_configvalue(args[0], result);
+		std::string value = ConfigParser::evaluate_backticks(args[1]);
+		utils::trim_end(value);
+		const auto& key = args[0];
+		const auto result = cfg->set_configvalue(key, value);
+		if (!result) {
+			v.get_statusline().show_error(strprintf::fmt(_("error setting '%s' to '%s': %s"),
+					key,
+					value,
+					result.error()));
+		}
 		// because some configuration value might have changed something UI-related
 		set_redraw(true);
 	} else {
@@ -276,7 +276,7 @@ void FormAction::handle_source(const std::vector<std::string>& args)
 	} else {
 		for (const auto& param : args) {
 			try {
-				v.get_ctrl()->load_configfile(
+				v.get_ctrl().load_configfile(
 					utils::resolve_tilde(
 						param));
 			} catch (const ConfigException& ex) {
@@ -292,7 +292,7 @@ void FormAction::handle_dumpconfig(const std::vector<std::string>& args)
 	if (args.size() != 1) {
 		v.get_statusline().show_error(_("usage: dumpconfig <file>"));
 	} else {
-		v.get_ctrl()->dump_config(
+		v.get_ctrl().dump_config(
 			utils::resolve_tilde(args[0]));
 		v.get_statusline().show_message(strprintf::fmt(
 				_("Saved configuration to %s"),
@@ -427,7 +427,7 @@ bool FormAction::handle_single_argument_set(std::string argument)
 }
 
 void FormAction::start_qna(const std::vector<QnaPair>& prompts,
-	Operation finish_op,
+	QnaFinishAction finish_op,
 	History* h)
 {
 	/*
@@ -447,7 +447,7 @@ void FormAction::start_qna(const std::vector<QnaPair>& prompts,
 	 */
 	qna_prompts = prompts;
 	qna_responses.clear();
-	finish_operation = finish_op;
+	qna_finish_operation = finish_op;
 	qna_history = h;
 	v.inside_qna(true);
 	start_next_question();
@@ -492,7 +492,7 @@ void FormAction::qna_previous_history()
 	}
 }
 
-void FormAction::finished_qna(Operation op)
+void FormAction::finished_qna(QnaFinishAction op)
 {
 	v.inside_qna(false);
 	v.inside_cmdline(false);
@@ -507,7 +507,7 @@ void FormAction::finished_qna(Operation op)
 	 * 	- run operation (in this case, save the bookmark)
 	 * 	- signal success (or failure) to the user
 	 */
-	case OP_INT_BM_END: {
+	case QnaFinishAction::Bookmark: {
 		assert(qna_responses.size() == 4 &&
 			qna_prompts.size() == 0); // everything must be answered
 		v.get_statusline().show_message(_("Saving bookmark..."));
@@ -527,7 +527,7 @@ void FormAction::finished_qna(Operation op)
 		}
 	}
 	break;
-	case OP_INT_END_CMDLINE: {
+	case QnaFinishAction::RunCmdLine: {
 		f.set_focus(main_widget());
 		std::string cmdline = qna_responses[0];
 		FormAction::cmdlinehistory.add_line(cmdline);
@@ -580,7 +580,7 @@ void FormAction::start_bookmark_qna(const std::string& default_title,
 
 		// if url or title is missing, abort autopilot and ask user
 		if (default_url.empty() || title.empty()) {
-			start_qna(prompts, OP_INT_BM_END);
+			start_qna(prompts, QnaFinishAction::Bookmark);
 		} else {
 			v.get_statusline().show_message(_("Saving bookmark on autopilot..."));
 			std::string retval = bookmark(default_url,
@@ -600,7 +600,7 @@ void FormAction::start_bookmark_qna(const std::string& default_title,
 			}
 		}
 	} else {
-		start_qna(prompts, OP_INT_BM_END);
+		start_qna(prompts, QnaFinishAction::Bookmark);
 	}
 }
 
@@ -670,7 +670,7 @@ void FormAction::start_next_question()
 
 		f.set_focus(main_widget());
 
-		this->finished_qna(finish_operation);
+		this->finished_qna(qna_finish_operation);
 	}
 }
 
