@@ -1,8 +1,5 @@
 #include "pbcontroller.h"
 
-#include <cinttypes>
-#include <cstdint>
-#include <cstdio>
 #include <cstdlib>
 #include <cstring>
 #include <getopt.h>
@@ -21,7 +18,6 @@
 #include "configexception.h"
 #include "configparser.h"
 #include "logger.h"
-#include "matcherexception.h"
 #include "nullconfigactionhandler.h"
 #include "pbview.h"
 #include "poddlthread.h"
@@ -278,6 +274,7 @@ void PbController::initialize(int argc, char* argv[])
 	cfg.register_commands(cfgparser);
 	colorman.register_commands(cfgparser);
 
+	cfgparser.register_handler("bind", keys);
 	cfgparser.register_handler("bind-key", keys);
 	cfgparser.register_handler("unbind-key", keys);
 
@@ -353,20 +350,20 @@ void PbController::print_usage(const char* argv0)
 		{
 			'C',
 			"config-file",
-			_s("<configfile>"),
-			_s("read configuration from <configfile>")
+			_s("<file>"),
+			_s("read configuration from <file>")
 		},
 		{
 			'q',
 			"queue-file",
-			_s("<queuefile>"),
-			_s("use <queuefile> as queue file")
+			_s("<file>"),
+			_s("use <file> as podcast queue file")
 		},
 		{
 			'-',
 			"lock-file",
-			_s("<lockfile>"),
-			_s("use <lockfile> as lock file")
+			_s("<file>"),
+			_s("use <file> as lock file")
 		},
 		{'a', "autodownload", "", _s("start download on startup")},
 		{
@@ -379,12 +376,14 @@ void PbController::print_usage(const char* argv0)
 		{
 			'd',
 			"log-file",
-			_s("<logfile>"),
-			_s("use <logfile> as output log file")
+			_s("<file>"),
+			_s("use <file> as output log file")
 		},
 		{'h', "help", "", _s("this help")}
 	};
 
+	std::vector<std::pair<std::string, std::string>> helpLines;
+	std::size_t maxLength = 0;
 	for (const auto& a : args) {
 		std::string longcolumn;
 		if (a.name != '-') {
@@ -396,15 +395,19 @@ void PbController::print_usage(const char* argv0)
 		}
 		longcolumn += "--" + a.longname;
 		longcolumn += a.params.size() > 0 ? "=" + a.params : "";
-		std::cout << "\t" << longcolumn;
-		for (unsigned int j = 0; j < utils::gentabs(longcolumn); j++) {
-			std::cout << "\t";
-		}
-		std::cout << a.desc << std::endl;
-	}
 
-	std::cout << std::endl
-		<< _("Support at #newsboat at https://libera.chat or on our mailing "
+		maxLength = std::max(maxLength, longcolumn.length());
+		helpLines.push_back({longcolumn, a.desc});
+	}
+	for (const auto& helpLine : helpLines) {
+		std::cout << std::string(8, ' ') << helpLine.first;
+		const auto padding = maxLength - helpLine.first.length();
+		std::cout << std::string(2 + padding, ' ') << helpLine.second;
+		std::cout << std::endl;
+	}
+	std::cout << std::endl;
+
+	std::cout << _("Support at #newsboat at https://libera.chat or on our mailing "
 			"list https://groups.google.com/g/newsboat")
 		<< std::endl
 		<< _("For more information, check out https://newsboat.org/")
