@@ -61,19 +61,19 @@ bool ctrl_c_hit = false;
 
 namespace newsboat {
 
-View::View(Controller* c)
+View::View(Controller& c)
 	: ctrl(c)
 	, cfg(0)
 	, keys(0)
 	, current_formaction(0)
 	, status_line(*this)
-	, rxman(c->get_regexmanager())
+	, rxman(c.get_regexmanager())
 	, is_inside_qna(false)
 	, is_inside_cmdline(false)
 	, tab_count(0)
 	, rsscache(nullptr)
-	, filters(ctrl->get_filtercontainer())
-	, colorman(ctrl->get_colormanager())
+	, filters(ctrl.get_filtercontainer())
+	, colorman(ctrl.get_colormanager())
 {
 	if (getenv("ESCDELAY") == nullptr) {
 		set_escdelay(25);
@@ -127,7 +127,7 @@ StatusLine& View::get_statusline()
 	return status_line;
 }
 
-bool View::run_commands(const std::vector<MacroCmd>& commands)
+bool View::run_commands(const std::vector<MacroCmd>& commands, BindingType binding_type)
 {
 	for (auto command : commands) {
 		if (formaction_stack_size() == 0) {
@@ -136,7 +136,7 @@ bool View::run_commands(const std::vector<MacroCmd>& commands)
 		std::shared_ptr<FormAction> fa = get_current_formaction();
 		fa->prepare();
 		fa->draw_form();
-		if (!fa->process_op(command.op, command.args, BindingType::Macro)) {
+		if (!fa->process_op(command.op, command.args, binding_type)) {
 			// Operation failed, abort
 			return false;
 		}
@@ -160,7 +160,7 @@ int View::run()
 
 	curs_set(0);
 
-	if (!run_commands(keys->get_startup_operation_sequence())) {
+	if (!run_commands(keys->get_startup_operation_sequence(), BindingType::Macro)) {
 		Stfl::reset();
 		std::cerr << _("Error: failed to execute startup commands") << std::endl;
 		return EXIT_FAILURE;
@@ -170,6 +170,7 @@ int View::run()
 	 * This is the main "event" loop of newsboat.
 	 */
 
+	std::vector<KeyCombination> key_sequence;
 	while (formaction_stack_size() > 0) {
 		// first, we take the current formaction.
 		std::shared_ptr<FormAction> fa = get_current_formaction();
@@ -215,24 +216,27 @@ int View::run()
 			LOG(Level::DEBUG,
 				"View::run: running macro `%s'",
 				event);
-			run_commands(keys->get_macro(key_combination));
+			run_commands(keys->get_macro(key_combination), BindingType::Macro);
 		} else {
-			const Operation op = keys->get_operation(key_combination, fa->id());
-
-			LOG(Level::DEBUG,
-				"View::run: event = %s op = %u",
-				event,
-				op);
-
-			if (OP_MACROPREFIX == op) {
-				have_macroprefix = true;
-				status_line.show_message("macro-");
+			if (key_combination == KeyCombination("ESC") && !key_sequence.empty()) {
+				key_sequence.clear();
+			} else {
+				key_sequence.push_back(key_combination);
 			}
+			auto binding_state = MultiKeyBindingState::NotFound;
+			BindingType type = BindingType::Bind;
+			auto cmds = keys->get_operation(key_sequence, fa->id(), binding_state, type);
 
-			// now we handle the operation to the
-			// formaction.
-			const std::vector<std::string> args;
-			fa->process_op(op, args);
+			if (binding_state != MultiKeyBindingState::MoreInputNeeded) {
+				key_sequence.clear();
+
+				run_commands(cmds, type);
+
+				if (cmds.size() >= 1 && cmds.back().op == OP_MACROPREFIX) {
+					have_macroprefix = true;
+					status_line.show_message("macro-");
+				}
+			}
 		}
 	}
 
@@ -259,6 +263,7 @@ std::string View::run_modal(std::shared_ptr<FormAction> f,
 	formaction_stack.push_back(f);
 	current_formaction = formaction_stack_size() - 1;
 
+	std::vector<KeyCombination> key_sequence;
 	while (formaction_stack.size() > stacksize) {
 		std::shared_ptr<FormAction> fa = get_current_formaction();
 
@@ -280,20 +285,48 @@ std::string View::run_modal(std::shared_ptr<FormAction> f,
 		}
 
 		const auto key_combination = KeyCombination::from_bindkey(event);
-		Operation op = keys->get_operation(key_combination, fa->id());
-
-		if (OP_REDRAW == op) {
-			Stfl::reset();
-			continue;
+		if (key_combination == KeyCombination("ESC") && !key_sequence.empty()) {
+			key_sequence.clear();
+		} else {
+			key_sequence.push_back(key_combination);
 		}
 
-		if (ignoredOperations.count(op)) {
-			status_line.show_message(_("Operation ignored in modal dialog"));
-			continue;
-		}
+		auto binding_state = MultiKeyBindingState::NotFound;
+		BindingType type = BindingType::Bind;
+		auto cmds = keys->get_operation(key_sequence, fa->id(), binding_state, type);
 
-		const std::vector<std::string> args;
-		fa->process_op(op, args);
+		if (binding_state != MultiKeyBindingState::MoreInputNeeded) {
+			key_sequence.clear();
+
+			for (auto command : cmds) {
+				if (formaction_stack_size() == 0) {
+					break;
+				}
+
+				if (OP_REDRAW == command.op) {
+					Stfl::reset();
+					continue;
+				}
+
+				if (ignoredOperations.count(command.op)) {
+					status_line.show_message(_("Operation ignored in modal dialog"));
+					break;
+				}
+
+				std::shared_ptr<FormAction> fa = get_current_formaction();
+				fa->prepare();
+				fa->draw_form();
+				if (!fa->process_op(command.op, command.args, type)) {
+					// Operation failed, don't run further commands
+					break;
+				}
+
+				if (formaction_stack.size() <= stacksize) {
+					// Stop running further commands if the current modal FormAction gets closed
+					break;
+				}
+			}
+		}
 	}
 
 	if (value.empty()) {
@@ -506,7 +539,7 @@ std::shared_ptr<ItemListFormAction> View::push_itemlist(
 void View::push_itemlist(unsigned int pos)
 {
 	std::shared_ptr<RssFeed> feed =
-		ctrl->get_feedcontainer()->get_feed(pos);
+		ctrl.get_feedcontainer()->get_feed(pos);
 	LOG(Level::DEBUG,
 		"View::push_itemlist: retrieved feed at position %d",
 		pos);
@@ -541,13 +574,13 @@ void View::push_itemview(std::shared_ptr<RssFeed> f,
 		current_formaction = formaction_stack_size() - 1;
 	} else {
 		std::shared_ptr<RssItem> item = f->get_item_by_guid(guid);
-		std::string filename = get_ctrl()->write_temporary_item(*item);
+		std::string filename = ctrl.write_temporary_item(*item);
 		open_in_pager(filename);
 		try {
 			bool old_unread = item->unread();
 			item->set_unread(false);
 			if (old_unread) {
-				get_ctrl()->mark_article_read(
+				ctrl.mark_article_read(
 					item->guid(), true);
 			}
 		} catch (const DbException& e) {
@@ -978,7 +1011,7 @@ void View::prepare_query_feed(std::shared_ptr<RssFeed> feed)
 
 		const std::shared_ptr<AutoDiscardMessage> message =
 			status_line.show_message_until_finished(_("Updating query feed..."));
-		feed->update_items(ctrl->get_feedcontainer()->get_all_feeds());
+		feed->update_items(ctrl.get_feedcontainer()->get_all_feeds());
 		feed->sort(cfg->get_article_sort_strategy());
 		notify_itemlist_change(feed);
 	}
