@@ -7,6 +7,7 @@
 #include "3rd-party/catch.hpp"
 
 #include "configexception.h"
+#include "keycombination.h"
 #include "keymap.h"
 #include "test_helpers/envvar.h"
 #include "test_helpers/tempfile.h"
@@ -182,7 +183,12 @@ TEST_CASE("evaluate_backticks replaces command in backticks with its output",
 		KeyMap keys(KM_NEWSBOAT);
 		cfgparser.register_handler("bind-key", keys);
 		REQUIRE_NOTHROW(cfgparser.parse_file("data/config-space-backticks"));
-		REQUIRE(keys.get_operation("s", "feedlist") == OP_SORT);
+		MultiKeyBindingState binding_state{};
+		BindingType binding_type{};
+		const auto& cmds = keys.get_operation({KeyCombination("s")}, "feedlist", binding_state,
+				binding_type);
+		REQUIRE(cmds.size() == 1);
+		REQUIRE(cmds.at(0).op == OP_SORT);
 	}
 
 	SECTION("Unbalanced backtick does *not* start a command") {
@@ -223,9 +229,9 @@ TEST_CASE("\"unbind-key -a\" removes all key bindings", "[ConfigParser]")
 
 		for (int i = OP_QUIT; i < OP_NB_MAX; ++i) {
 			REQUIRE(keys.get_keys(static_cast<Operation>(i),
-					"feedlist") == std::vector<std::string>());
+					"feedlist") == std::vector<KeyCombination>());
 			REQUIRE(keys.get_keys(static_cast<Operation>(i),
-					"podboat") == std::vector<std::string>());
+					"podboat") == std::vector<KeyCombination>());
 		}
 	}
 
@@ -243,11 +249,32 @@ TEST_CASE("\"unbind-key -a\" removes all key bindings", "[ConfigParser]")
 
 		for (int i = OP_QUIT; i < OP_NB_MAX; ++i) {
 			REQUIRE(keys.get_keys(static_cast<Operation>(i),
-					"article") == std::vector<std::string>());
+					"article") == std::vector<KeyCombination>());
 		}
 	}
 }
 
+TEST_CASE("Concatenates lines that end with a backslash", "[ConfigParser]")
+{
+	ConfigParser cfgparser;
+	KeyMap k(KM_NEWSBOAT);
+	cfgparser.register_handler("macro", k);
+	REQUIRE_NOTHROW(cfgparser.parse_file("data/config-multi-line"));
+	auto p_macro = k.get_macro(KeyCombination("p"));
+	REQUIRE(!p_macro.empty());
+	REQUIRE(p_macro[0].op == newsboat::OP_OPEN);
+	REQUIRE(p_macro[1].op == newsboat::OP_RELOAD);
+	REQUIRE(p_macro[2].op == newsboat::OP_QUIT);
+	REQUIRE(p_macro[3].op == newsboat::OP_QUIT);
+
+	auto contrived = k.get_macro(KeyCombination("j"));
+	REQUIRE(!contrived.empty());
+	REQUIRE(contrived[0].op == newsboat::OP_QUIT);
+	REQUIRE(contrived[1].op == newsboat::OP_QUIT);
+	REQUIRE(contrived[2].op == newsboat::OP_QUIT);
+	REQUIRE(contrived[3].op == newsboat::OP_QUIT);
+}
+
 TEST_CASE("`include` directive includes other config files", "[ConfigParser]")
 {
 	// TODO: error messages should be more descriptive than "file couldn't be opened"
