@@ -8,7 +8,6 @@
 #include "cache.h"
 #include "configpaths.h"
 #include "controller.h"
-#include "feedlistformaction.h"
 #include "itemlist.h"
 #include "keymap.h"
 #include "regexmanager.h"
@@ -23,7 +22,7 @@ TEST_CASE("OP_OPEN displays article using an external pager",
 {
 	ConfigPaths paths;
 	Controller c(paths);
-	newsboat::View v(&c);
+	newsboat::View v(c);
 	test_helpers::TempFile pagerfile;
 
 	const std::string test_url = "http://test_url";
@@ -77,7 +76,7 @@ TEST_CASE("OP_PURGE_DELETED purges previously deleted items",
 {
 	ConfigPaths paths;
 	Controller c(paths);
-	newsboat::View v(&c);
+	newsboat::View v(c);
 	ConfigContainer cfg;
 	Cache rsscache(":memory:", &cfg);
 	FilterContainer filters;
@@ -112,7 +111,7 @@ TEST_CASE(
 {
 	ConfigPaths paths;
 	Controller c(paths);
-	newsboat::View v(&c);
+	newsboat::View v(c);
 	test_helpers::TempFile browserfile;
 
 	const std::string test_url = "http://test_url";
@@ -152,7 +151,7 @@ TEST_CASE(
 {
 	ConfigPaths paths;
 	Controller c(paths);
-	newsboat::View v(&c);
+	newsboat::View v(c);
 
 	const std::string test_url = "http://test_url";
 
@@ -185,7 +184,7 @@ TEST_CASE("OP_OPENINBROWSER passes the url to the browser",
 {
 	ConfigPaths paths;
 	Controller c(paths);
-	newsboat::View v(&c);
+	newsboat::View v(c);
 	test_helpers::TempFile browserfile;
 	const std::string test_url = "http://test_url";
 	std::string line;
@@ -220,7 +219,7 @@ TEST_CASE("OP_OPENINBROWSER_NONINTERACTIVE passes the url to the browser",
 {
 	ConfigPaths paths;
 	Controller c(paths);
-	newsboat::View v(&c);
+	newsboat::View v(c);
 	test_helpers::TempFile browserfile;
 	const std::string test_url = "http://test_url";
 	std::string line;
@@ -255,7 +254,7 @@ TEST_CASE("OP_OPENALLUNREADINBROWSER passes the url list to the browser",
 {
 	ConfigPaths paths;
 	Controller c(paths);
-	newsboat::View v(&c);
+	newsboat::View v(c);
 	test_helpers::TempFile browserfile;
 	std::unordered_set<std::string> url_set;
 	const std::string test_url = "http://test_url";
@@ -301,7 +300,7 @@ TEST_CASE("OP_OPENALLUNREADINBROWSER passes the url list to the browser",
 			while (std::getline(browserFileStream, line)) {
 				INFO("Each URL should be present exactly once. "
 					"Erase urls after first match to fail if "
-					"an item opens twice.")
+					"an item opens twice.");
 				REQUIRE(url_set.count(line) == 1);
 				url_set.erase(url_set.find(line));
 				openedItemsCount += 1;
@@ -324,7 +323,7 @@ TEST_CASE("OP_OPENALLUNREADINBROWSER passes the url list to the browser",
 			while (std::getline(browserFileStream, line)) {
 				INFO("Each URL should be present exactly once. "
 					"Erase urls after first match to fail if "
-					"an item opens twice.")
+					"an item opens twice.");
 				REQUIRE(url_set.count(line) == 1);
 				url_set.erase(url_set.find(line));
 				openedItemsCount += 1;
@@ -341,7 +340,7 @@ TEST_CASE(
 {
 	ConfigPaths paths;
 	Controller c(paths);
-	newsboat::View v(&c);
+	newsboat::View v(c);
 	test_helpers::TempFile browserfile;
 	std::unordered_set<std::string> url_set;
 	const std::string test_url = "http://test_url";
@@ -386,7 +385,7 @@ TEST_CASE(
 			while (std::getline(browserFileStream, line)) {
 				INFO("Each URL should be present exactly once. "
 					"Erase urls after first match to fail if "
-					"an item opens twice.")
+					"an item opens twice.");
 				REQUIRE(url_set.count(line) == 1);
 				url_set.erase(url_set.find(line));
 				openedItemsCount += 1;
@@ -411,7 +410,7 @@ TEST_CASE(
 			while (std::getline(browserFileStream, line)) {
 				INFO("Each URL should be present exactly once. "
 					"Erase urls after first match to fail if "
-					"an item opens twice.")
+					"an item opens twice.");
 				REQUIRE(url_set.count(line) == 1);
 				url_set.erase(url_set.find(line));
 				openedItemsCount += 1;
@@ -426,7 +425,7 @@ TEST_CASE("OP_SHOWURLS shows the article's properties", "[ItemListFormAction]")
 {
 	ConfigPaths paths;
 	Controller c(paths);
-	newsboat::View v(&c);
+	newsboat::View v(c);
 	ConfigContainer cfg;
 	Cache rsscache(":memory:", &cfg);
 	FilterContainer filters;
@@ -492,7 +491,7 @@ TEST_CASE("OP_BOOKMARK pipes articles url and title to bookmark-command",
 {
 	ConfigPaths paths;
 	Controller c(paths);
-	newsboat::View v(&c);
+	newsboat::View v(c);
 	ConfigContainer cfg;
 	Cache rsscache(":memory:", &cfg);
 	FilterContainer filters;
@@ -555,7 +554,7 @@ TEST_CASE("OP_EDITFLAGS arguments are added to an item's flags",
 {
 	ConfigPaths paths;
 	Controller c(paths);
-	newsboat::View v(&c);
+	newsboat::View v(c);
 	ConfigContainer cfg;
 	Cache rsscache(":memory:", &cfg);
 	FilterContainer filters;
@@ -613,7 +612,7 @@ TEST_CASE("OP_SAVE writes an article's attributes to the specified file",
 {
 	ConfigPaths paths;
 	Controller c(paths);
-	newsboat::View v(&c);
+	newsboat::View v(c);
 	test_helpers::TempFile saveFile;
 	ConfigContainer cfg;
 	Cache rsscache(":memory:", &cfg);
@@ -676,7 +675,7 @@ TEST_CASE("OP_HELP command is processed", "[ItemListFormAction]")
 {
 	ConfigPaths paths;
 	Controller c(paths);
-	newsboat::View v(&c);
+	newsboat::View v(c);
 	ConfigContainer cfg;
 	Cache rsscache(":memory:", &cfg);
 
@@ -701,7 +700,7 @@ TEST_CASE("OP_HARDQUIT command is processed", "[ItemListFormAction]")
 {
 	ConfigPaths paths;
 	Controller c(paths);
-	newsboat::View v(&c);
+	newsboat::View v(c);
 	ConfigContainer cfg;
 	Cache rsscache(":memory:", &cfg);
 	FilterContainer filters;
@@ -731,7 +730,7 @@ TEST_CASE("Navigate back and forth using OP_NEXT and OP_PREV",
 	ConfigPaths paths;
 	Controller c(paths);
 	test_helpers::TempFile articleFile;
-	newsboat::View v(&c);
+	newsboat::View v(c);
 	ConfigContainer cfg;
 	cfg.set_configvalue(
 		"external-url-viewer", "tee > " + articleFile.get_path());
@@ -781,7 +780,7 @@ TEST_CASE("OP_TOGGLESHOWREAD switches the value of show-read-articles",
 {
 	ConfigPaths paths;
 	Controller c(paths);
-	newsboat::View v(&c);
+	newsboat::View v(c);
 	ConfigContainer cfg;
 	Cache rsscache(":memory:", &cfg);
 
@@ -819,7 +818,7 @@ TEST_CASE("OP_PIPE_TO pipes an article's content to an external command",
 {
 	ConfigPaths paths;
 	Controller c(paths);
-	newsboat::View v(&c);
+	newsboat::View v(c);
 	test_helpers::TempFile articleFile;
 	ConfigContainer cfg;
 	Cache rsscache(":memory:", &cfg);
@@ -884,7 +883,7 @@ TEST_CASE("OP_OPENINBROWSER does not result in itemlist invalidation",
 	Controller c(paths);
 	ConfigContainer cfg;
 	KeyMap k(KM_NEWSBOAT);
-	newsboat::View v(&c);
+	newsboat::View v(c);
 	v.set_config_container(&cfg);
 	v.set_keymap(&k);
 	Cache rsscache(":memory:", &cfg);
